@@ -41,7 +41,7 @@ impl<C: Clone> Matrix<C> {
     }
 
     /// Return a copy of a sub-matrix.
-    #[cfg_attr(feature = "cargo-clippy", allow(needless_pass_by_value))]
+    #[cfg_attr(feature = "cargo-clippy", allow(clippy::needless_pass_by_value))]
     pub fn slice(&self, rows: Range<usize>, columns: Range<usize>) -> Matrix<C> {
         let height = rows.end - rows.start;
         let width = columns.end - columns.start;
