@@ -133,7 +133,7 @@ where
 ///
 /// This function returns a map between every vertex and the index of
 /// the set it belongs to in the `components` list.
-#[cfg_attr(feature = "cargo-clippy", allow(implicit_hasher))]
+#[cfg_attr(feature = "cargo-clippy", allow(clippy::implicit_hasher))]
 pub fn component_index<N>(components: &[HashSet<N>]) -> HashMap<N, usize>
 where
     N: Clone + Hash + Eq,
